inputs_precede_memtables

Function inputs_precede_memtables 

pub(super) fn inputs_precede_memtables(
    inputs: &[FileHandle],
    memtable_min_sequence: Option<SequenceNumber>,
) -> bool
Imported SSTs can be newer than pending writes. A merge must not attach an old field to a sequence above an intermediate version left in a memtable.